summaryrefslogtreecommitdiffstats
path: root/karbon/render
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/render')
-rw-r--r--karbon/render/xrgbrender/gdk-pixbuf-xlib-drawable.c8
-rw-r--r--karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c16
-rw-r--r--karbon/render/xrgbrender/gdk-pixbuf-xlib.h2
3 files changed, 13 insertions, 13 deletions
diff --git a/karbon/render/xrgbrender/gdk-pixbuf-xlib-drawable.c b/karbon/render/xrgbrender/gdk-pixbuf-xlib-drawable.c
index bbafa393..b9cf9376 100644
--- a/karbon/render/xrgbrender/gdk-pixbuf-xlib-drawable.c
+++ b/karbon/render/xrgbrender/gdk-pixbuf-xlib-drawable.c
@@ -1103,7 +1103,7 @@ xlib_window_is_viewable (Window w)
XWindowAttributes wa;
while (w != 0) {
- Window tqparent, root, *tqchildren;
+ Window parent, root, *tqchildren;
int ntqchildren;
XGetWindowAttributes (gdk_pixbuf_dpy, w, &wa);
@@ -1111,16 +1111,16 @@ xlib_window_is_viewable (Window w)
return 0;
if (!XQueryTree (gdk_pixbuf_dpy, w, &root,
- &tqparent, &tqchildren, &ntqchildren))
+ &parent, &tqchildren, &ntqchildren))
return 0;
if (ntqchildren > 0)
XFree (tqchildren);
- if (tqparent == root)
+ if (parent == root)
return 1;
- w = tqparent;
+ w = parent;
}
return 0;
diff --git a/karbon/render/xrgbrender/gdk-pixbuf-xlib.h b/karbon/render/xrgbrender/gdk-pixbuf-xlib.h
index 63961ea7..2b31ed7e 100644
--- a/karbon/render/xrgbrender/gdk-pixbuf-xlib.h
+++ b/karbon/render/xrgbrender/gdk-pixbuf-xlib.h
@@ -63,7 +63,7 @@ void gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf,
XlibRgbDither dither,
int x_dither, int y_dither);
-void gdk_pixbuf_xlib_render_pixmap_and_tqmask (GdkPixbuf *pixbuf,
+void gdk_pixbuf_xlib_render_pixmap_and_mask (GdkPixbuf *pixbuf,
Pixmap *pixmap_return,
Pixmap *mask_return,
int alpha_threshold);
diff --git a/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c b/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c
index be1a839c..f2439138 100644
--- a/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c
+++ b/karbon/render/xrgbrender/gdk-pixbuf-xlib-render.c
@@ -31,7 +31,7 @@
**
* gdk_pixbuf_xlib_render_threshold_alpha:
* @pixbuf: A pixbuf.
* @bitmap: Bitmap where the bilevel tqmask will be painted to.
* @src_x: Source X coordinate.
* @src_y: source Y coordinate.
* @dest_x: Destination X coordinate.
@@ -42,7 +42,7 @@
* other values will be painted as one.
*
* Takes the opacity values in a rectangular portion of a pixbuf and thresholds
* them to produce a bi-level alpha tqmask that can be used as a clipping tqmask for
* a drawable.
*
void
@@ -177,7 +177,7 @@ remove_alpha (GdkPixbuf *pixbuf, int x, int y, int width, int height, int *rowst
* specified GC. This is done using XlibRGB, so the specified drawable must
* have the XlibRGB visual and colormap. Note that this function will ignore
* the opacity information for images with an alpha channel; the GC must already
* have the clipping tqmask set if you want transparent regions to show through.
*
* For an explanation of dither offsets, see the XlibRGB documentation. In
* brief, the dither offset is important when re-rendering partial regions of an
@@ -255,7 +255,7 @@ gdk_pixbuf_xlib_render_to_drawable (GdkPixbuf *pixbuf,
*
* When used with #GDK_PIXBUF_ALPHA_BILEVEL, this function has to create a bitmap
* out of the thresholded alpha channel of the image and, it has to set this
* bitmap as the clipping tqmask for the GC used for drawing. This can be a
* significant performance penalty depending on the size and the complexity of
* the alpha channel of the image. If performance is crucial, consider handling
* the alpha channel yourself (possibly by caching it in your application) and
@@ -320,12 +320,12 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
* @pixbuf: A pixbuf.
* @pixmap_return: Return value for the created pixmap.
- * @mask_return: Return value for the created tqmask.
+ * @mask_return: Return value for the created mask.
* @alpha_threshold: Threshold value for opacity values.
*
* Creates a pixmap and a tqmask bitmap which are returned in the @pixmap_return
* and @mask_return arguments, respectively, and renders a pixbuf and its
* corresponding tresholded alpha tqmask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
* given drawables should use gdk_pixbuf_xlib_render_to_drawable_alpha() or
* gdk_pixbuf_xlib_render_to_drawable(), and
@@ -334,7 +334,7 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
* If the pixbuf does not have an alpha channel, then *@mask_return will be set
* to None.
void
-gdk_pixbuf_xlib_render_pixmap_and_tqmask (GdkPixbuf *pixbuf,
+gdk_pixbuf_xlib_render_pixmap_and_mask (GdkPixbuf *pixbuf,
Pixmap *pixmap_return,
Pixmap *mask_return,
int alpha_threshold)
@@ -31,7 +31,7 @@
* gdk_pixbuf_xlib_render_threshold_alpha:
* @pixbuf: A pixbuf.
- * @bitmap: Bitmap where the bilevel tqmask will be painted to.
+ * @bitmap: Bitmap where the bilevel mask will be painted to.
* @src_x: Source X coordinate.
* @src_y: source Y coordinate.
@@ -42,7 +42,7 @@
*
* Takes the opacity values in a rectangular portion of a pixbuf and thresholds
- * them to produce a bi-level alpha tqmask that can be used as a clipping tqmask for
+ * them to produce a bi-level alpha mask that can be used as a clipping mask for
* a drawable.
*
@@ -177,7 +177,7 @@ remove_alpha (GdkPixbuf *pixbuf, int x, int y, int width, int height, int *rowst
* have the XlibRGB visual and colormap. Note that this function will ignore
* the opacity information for images with an alpha channel; the GC must already
- * have the clipping tqmask set if you want transparent regions to show through.
+ * have the clipping mask set if you want transparent regions to show through.
*
* For an explanation of dither offsets, see the XlibRGB documentation. In
@@ -255,7 +255,7 @@ gdk_pixbuf_xlib_render_to_drawable (GdkPixbuf *pixbuf,
* When used with #GDK_PIXBUF_ALPHA_BILEVEL, this function has to create a bitmap
* out of the thresholded alpha channel of the image and, it has to set this
- * bitmap as the clipping tqmask for the GC used for drawing. This can be a
+ * bitmap as the clipping mask for the GC used for drawing. This can be a
* significant performance penalty depending on the size and the complexity of
* the alpha channel of the image. If performance is crucial, consider handling
@@ -320,12 +320,12 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
* @alpha_threshold: Threshold value for opacity values.
*
- * Creates a pixmap and a tqmask bitmap which are returned in the @pixmap_return
+ * Creates a pixmap and a mask bitmap which are returned in the @pixmap_return
* and @mask_return arguments, respectively, and renders a pixbuf and its
@@ -320,12 +320,12 @@ gdk_pixbuf_xlib_render_to_drawable_alpha (GdkPixbuf *pixbuf, Drawable drawable,
* and @mask_return arguments, respectively, and renders a pixbuf and its
- * corresponding tresholded alpha tqmask to them. This is merely a convenience
+ * corresponding tresholded alpha mask to them. This is merely a convenience
* function; applications that need to render pixbufs with dither offsets or to
* given drawables should use gdk_pixbuf_xlib_render_to_drawable_alpha() or